# Contributors
This file describes the contributors to the NetIF library and the software used as part of this project. It is part of the GMLC-TDC project and used in the HELICS project.  HELICS is a joint project between PNNL, LLNL, and NREL, with contributions from many other national Labs
If you would like to contribute to the NetIF, HELICS or any of the GMLC-TDC related repositories see [CONTRIBUTING](CONTRIBUTING.md)

## Individual contributors

### Lawrence Livermore National Lab
 - Philip Top
 - Ryan Mast`

### National Renewable Energy Lab
 - Dheepak Krishnamurthy

## Used Libraries or Code

### [HELICS](https://github.com/GMLC-TDC/HELICS)  
Most of the original code for this library was pulled from use inside HELICS. HELICS is released with a BSD-3-Clause license.

### [Catch2](https://github.com/catchorg/Catch2)
The Catch2 test framework is used for tests. Catch2 is released under the Boost Software License 1.0.
